package com.dragon.gateway.filter.impl;

import com.alibaba.fastjson2.JSONObject;
import com.dragon.common.core.constant.HttpStatus;
import com.dragon.common.core.constant.SecurityConstants;
import com.dragon.common.core.utils.ServletUtils;
import com.dragon.common.core.utils.SpringUtils;
import com.dragon.common.redis.service.RedisService;
import com.dragon.vehicle.firm.domain.cache.FirmInfoCache;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cloud.gateway.filter.GatewayFilter;
import org.springframework.cloud.gateway.filter.GatewayFilterChain;
import org.springframework.stereotype.Component;
import org.springframework.web.server.ServerWebExchange;
import reactor.core.publisher.Mono;

@Component
public class CacheRequestGatewayFilter implements GatewayFilter {



    private static Logger log = LoggerFactory.getLogger(CacheRequestGatewayFilter.class);

    @Override
    public Mono<Void> filter(ServerWebExchange exchange, GatewayFilterChain chain) {


        String userId = exchange.getRequest().getHeaders().getFirst(SecurityConstants.DETAILS_USER_ID);
        log.info("经过公司过滤器，{}", userId);
        log.info("请求的uri是:{}",exchange.getRequest().getPath().toString());
        if ("/firm/firm/by/userId".equals(exchange.getRequest().getPath().toString())){
            // GET DELETE 不过滤
            RedisService redisService = SpringUtils.getBean(RedisService.class);
            FirmInfoCache firmInfoCache = redisService.getCacheObject("company:" + userId);
            log.info("企业对象是{}:", JSONObject.toJSONString(firmInfoCache));

            if (firmInfoCache == null) {
                log.error("[鉴权异常处理]请求路径:{}", exchange.getRequest().getPath());
                return ServletUtils.webFluxResponseWriter(exchange.getResponse(), "您还未进行企业认证", HttpStatus.UNAUTHORIZED);
            }
            return chain.filter(exchange);
        }

        return chain.filter(exchange);
    }
}
